%GOTHROUGH  Go Through 
% generates the last two control points of a previous curve and the first
% two control points of a subsequent curve and appends them to CP
%
% Syntax:  CP = goThrough(CP, P, vel)
%
% Inputs:
%    CP - control point matrix
%    P - position of the end of the last curve/start of next curve
%    vel - required rate and direction (dr/dt) at which you want to travel through the point P
%
% Outputs:
%    CP - control point matrix
%
% See also: STARTCUBICBEZ, STOPCUBICBEZ

% Author: Travis Hydzik
% Last revision: 19 October 2004

function CP = goThrough(CP, P, vel)

    CP = [ CP
            P - vel/3
            P
            P
            P + vel/3 ];